![Python package](https://github.com/mqharris/533_lab2/workflows/Python%20package/badge.svg)

# 533 lab2
Group: Nathan Smith, Mitch Harris, Ryan Koenig

# Package: quickscreen

The quickscreen package provides simple tools for quickly reviewing a dataframe. The package includes three subpackages: one for plotting data, another for providing a simple summary statistics, and another which does simple manipulations and linear correlation. The package is basically a wrapper for various matplotlib and pandas functionality.

The following documentation is also provided:
- *description.md* provides an overview of the package including its subpackages and module classes and functions
- *example.ipynb* provides a demo file of the package usage
    - the demo file uses data availble in the CarPrice.csv file
    
